Crate muster_cli

Crate muster_cli 

CLI type definitions for muster.

This module defines the clap command structure used by the muster binary. It is exposed as a library target so that tools like clap-markdown can generate documentation from the type definitions.

Structs

Cli
Terminal session group management built on tmux.

Enums

Command
Top-level commands.
NotificationAction
Notification subcommands.
ProfileAction
Profile subcommands.